@@ -16,4 +16,4 @@ def run_unit_tests():
     result = run_simulations_test(pth_fwd=pth_fwd)
     print('\tPassed') if result else print('\tFailed')
     
-    # shutil.rmtree(pth_fwd)
\ No newline at end of file
+    shutil.rmtree(pth_fwd)
\ No newline at end of file
